pub enum InputCaptureMode {
Exclusive,
Passthrough,
}Expand description
How a captured scope behaves when it does not handle a key.
Variants
Exclusive
Stop routing when the captured scope does not handle the key.
Passthrough
Continue routing to older captures, focused bindings, and globals.